@@ -82,7 +82,7 @@ _S3_OPTS = [
 ]
 
 
-class UploadPart:
+class UploadPart(object):
 
     """
     The class for the upload part
@@ -294,7 +294,7 @@ class ChunkedFile(object):
 class Store(glance_store.driver.Store):
     """An implementation of the s3 adapter."""
 
-    _CAPABILITIES = capabilities.RW_ACCESS
+    _CAPABILITIES = capabilities.BitMasks.RW_ACCESS
     OPTIONS = _S3_OPTS
     EXAMPLE_URL = "s3://<ACCESS_KEY>:<SECRET_KEY>@<S3_URL>/<BUCKET>/<OBJ>"
 
@@ -642,7 +642,6 @@ class Store(glance_store.driver.Store):
                      {'obj_name': obj_name,
                       'UploadId': mpu.id,
                       'total_size': total_size,
-                      'obj_name': obj_name,
                       'checksum_hex': checksum_hex})
             return (loc.get_uri(), total_size, checksum_hex, {})
         else:
