@@ -104,7 +104,7 @@ class FakeKey(object):
         return self.data
 
 
-class FakeMPU:
+class FakeMPU(object):
     """
     Acts like a ``boto.s3.multipart.MultiPartUpload``
     """
@@ -167,7 +167,7 @@ class FakeMPU:
         return key
 
 
-class FakeBucket:
+class FakeBucket(object):
     """Acts like a ``boto.s3.bucket.Bucket``."""
     def __init__(self, name, keys=None):
         self.name = name
@@ -489,7 +489,8 @@ class TestStore(base.StoreBaseTest,
             self.config(**conf)
             self.store = s3.Store(self.conf)
             self.store.configure()
-            return not self.store.is_capable(capabilities.WRITE_ACCESS)
+            return not self.store.is_capable(
+                capabilities.BitMasks.WRITE_ACCESS)
         except Exception:
             return False
         return False
