@@ -23,10 +23,10 @@ import mock
 import tempfile
 import uuid
 
-import httpretty
 from oslo_config import cfg
 from oslo_utils import units
 from oslotest import moxstubout
+import requests_mock
 import six
 import StringIO
 import swiftclient
@@ -761,7 +761,8 @@ class SwiftTests(object):
         try:
             self.config(**conf)
             self.store = Store(self.conf)
-            return not self.store.is_capable(capabilities.WRITE_ACCESS)
+            return not self.store.is_capable(
+                capabilities.BitMasks.WRITE_ACCESS)
         except Exception:
             return False
         return False
@@ -775,7 +776,8 @@ class SwiftTests(object):
                                           'authurl.com', 'user': '',
                                           'key': ''}}
         self.store.configure()
-        self.assertFalse(self.store.is_capable(capabilities.WRITE_ACCESS))
+        self.assertFalse(self.store.is_capable(
+            capabilities.BitMasks.WRITE_ACCESS))
 
     def test_no_auth_address(self):
         """
@@ -786,7 +788,8 @@ class SwiftTests(object):
                                           '', 'user': 'user1',
                                           'key': 'key1'}}
         self.store.configure()
-        self.assertFalse(self.store.is_capable(capabilities.WRITE_ACCESS))
+        self.assertFalse(self.store.is_capable(
+            capabilities.BitMasks.WRITE_ACCESS))
 
     def test_delete(self):
         """
@@ -1207,42 +1210,29 @@ class TestMultiTenantStoreContext(base.StoreBaseTest):
         }]
         self.addCleanup(self.conf.reset)
 
-    @httpretty.activate
-    def test_download_context(self):
+    @requests_mock.mock()
+    def test_download_context(self, m):
         """Verify context (ie token) is passed to swift on download."""
         self.config(swift_store_multi_tenant=True)
         store = Store(self.conf)
         store.configure()
-        uri = "swift+http://127.0.0.1:0/glance_123/123"
+        uri = "swift+http://127.0.0.1/glance_123/123"
         loc = location.get_location_from_uri(uri, conf=self.conf)
         ctx = context.RequestContext(
             service_catalog=self.service_catalog, user='tenant:user1',
             tenant='tenant', auth_token='0123')
-        httpretty.register_uri(httpretty.GET,
-                               "http://127.0.0.1:0/glance_123/123",
-                               status=200)
+
+        m.get("http://127.0.0.1/glance_123/123")
         store.get(loc, context=ctx)
-        self.assertEqual(
-            '0123', httpretty.last_request().headers['X-Auth-Token'])
+        self.assertEqual('0123', m.last_request.headers['X-Auth-Token'])
 
-    @httpretty.activate
-    def test_upload_context(self):
+    @requests_mock.mock()
+    def test_upload_context(self, m):
         """Verify context (ie token) is passed to swift on upload."""
-        def put_callback(request, uri, headers):
-            self.assertEqual('Some data', request.body)
-            self.assertEqual('0123', request.headers['X-Auth-Token'])
-            return (201, headers, "")
-
-        def head_callback(request, uri, headers):
-            self.assertEqual('0123', request.headers['X-Auth-Token'])
-            return (200, headers, "")
-
-        httpretty.register_uri(httpretty.HEAD,
-                               "http://127.0.0.1:0/glance_123",
-                               head_callback)
-        httpretty.register_uri(httpretty.PUT,
-                               "http://127.0.0.1:0/glance_123/123",
-                               put_callback)
+        head_req = m.head("http://127.0.0.1/glance_123",
+                          text='Some data',
+                          status_code=201)
+        put_req = m.put("http://127.0.0.1/glance_123/123")
 
         self.config(swift_store_multi_tenant=True)
         store = Store(self.conf)
@@ -1253,8 +1243,9 @@ class TestMultiTenantStoreContext(base.StoreBaseTest):
             tenant='tenant', auth_token='0123')
         store.add('123', pseudo_file, pseudo_file.len,
                   context=ctx)
-        self.assertEqual(
-            '0123', httpretty.last_request().headers['X-Auth-Token'])
+
+        self.assertEqual('0123', head_req.last_request.headers['X-Auth-Token'])
+        self.assertEqual('0123', put_req.last_request.headers['X-Auth-Token'])
 
 
 class FakeGetEndpoint(object):
